@@ -266,6 +266,9 @@ class MATRIX:
                 except Exception as e:
                     traceback.print_exc()
                     print("File not valid: " + file)
+        for file in os.listdir(inject_dir):
+            if file.endswith(".png"):
+                os.remove(inject_dir + file)
         if not self.preserve:
             for file in os.listdir(inject_dir):
                 if file.endswith(".csv") and file.startswith("P"):
@@ -465,7 +468,7 @@ class MATRIX:
                 flux = flux[~intransit_result]
                 time, flux = cleaned_array(time, flux)
                 if results.transit_times is not None and len(results.transit_times) > 0:
-                    found_signal = HarmonicSelector.is_harmonic(results.period, period, results.transit_times[0], epoch)
+                    found_signal = HarmonicSelector.is_harmonic(results.transit_times[0], epoch, results.period, period)
                     if found_signal:
                         break
             run = run + 1
